StaticRenderTaskSurface

Enum StaticRenderTaskSurface 

pub enum StaticRenderTaskSurface {
    TextureCache {
        texture: CacheTextureId,
        target_kind: RenderTargetKind,
    },
    ReadOnly {
        source: TextureSource,
    },
    PictureCache {
        surface: ResolvedSurfaceTexture,
    },
}
A render task location that targets a persistent output buffer which will be retained over multiple frames.

Variants



TextureCache

The output of the RenderTask will be persisted beyond this frame, and thus should be drawn into the TextureCache.

Fields

texture: CacheTextureId

Which texture in the texture cache should be drawn into.

target_kind: RenderTargetKind

What format this texture cache surface is



ReadOnly

Only used as a source for render tasks, can be any texture including an external one.

Fields



PictureCache

This render task will be drawn to a picture cache texture that is persisted between both frames and scenes, if the content remains valid.

Fields

surface: ResolvedSurfaceTexture

Describes either a WR texture or a native OS compositor target