pub struct ImageClipSubTask {
pub quad_address: GpuBufferAddress,
pub quad_transform_id: GpuTransformId,
pub src_task: RenderTaskId,
pub quad_flags: QuadFlags,
pub needs_scissor_rect: bool,
}Expand description
An clip applied to a render task using the multiply blend mode on top of the content being clipped.
Fields
quad_address: GpuBufferAddressQuad primitive address for this clip.
quad_transform_id: GpuTransformIdTransform from the clip’s local space to raster space (to position the clip’s quad primitive).
src_task: RenderTaskIdquad_flags: QuadFlagsneeds_scissor_rect: boolTrait Implementations
Sourceimpl Debug for ImageClipSubTask
impl Debug for ImageClipSubTask