RectangleClipSubTask

Struct RectangleClipSubTask 

pub struct RectangleClipSubTask {
    pub quad_address: GpuBufferAddress,
    pub clip_address: GpuBufferAddress,
    pub clip_space: ClipSpace,
    pub quad_transform_id: GpuTransformId,
    pub clip_transform_id: GpuTransformId,
    pub quad_flags: QuadFlags,
    pub needs_scissor_rect: bool,
    pub rounded_rect_fast_path: bool,
}
A (rounded) rectangle clip applied to a render task using the multiply blend mode on top of the content being clipped.

Fields

quad_address: GpuBufferAddress

Quad primitive address for this clip.

clip_address: GpuBufferAddress

Location of the (rounded) rectangle parameters.

clip_space: ClipSpace

The coordinate space of the clip.

  • If primitive space, then the clip’s quad primitive is positioned using the transform of the primitive being clipped. clip_transform_id is used by the shader to map from that space to the clip’s local space. This is used when the clip and raster space are indifferent coordinate systems.
  • If raster space, then the clip’s quad primitive is positioned directly using rectangles in raster space (no transforms). The clip parameters are still potentially in a different space so clip_transform_id is used to map from raster to clip space (this transform is assumed to be a scale-offset).
quad_transform_id: GpuTransformId

Transform applied to the quad primitive of the clip.

clip_transform_id: GpuTransformId

Transform from the quad primitive’s space to the clip’s local space.

quad_flags: QuadFlagsneeds_scissor_rect: boolrounded_rect_fast_path: bool